.. -*- restructuredtext -*-

==============================
Contentui extension for Sphinx
==============================

This is a modified fork of Serge Domkowski's `examplecode extension
<https://bitbucket.org/birkenfeld/sphinx-contrib/src/7f39b7f255e34bfe588f0065a5d9709a7d8e7614/examplecode/?at=default>`_
for Sphinx.


About
=====

This is a simple extension that is rendered as HTML widgets:

- `Content tab <http://sphinxcontrib-contentui.readthedocs.io/en/latest/tabs.html>`_
- `Column content <http://sphinxcontrib-contentui.readthedocs.io/en/latest/columns.html>`_
- `Toggle header <http://sphinxcontrib-contentui.readthedocs.io/en/latest/toggle.html>`_


Example
-------

`All-in-One Example <http://sphinxcontrib-contentui.readthedocs.io/en/latest/example-all.html>`_


Installation
------------

.. code-block:: bash

    $ pip install sphinxcontrib-contentui


Enabling the extension in Sphinx
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Just add sphinxcontrib.contentui to the list of extensions in the **conf.py** file. For example:

.. code-block:: bash

    extensions = ['sphinxcontrib.contentui']


Documentation
-------------

Full documentation for end users can be found in the "docs" folder.

It is also available online on `Read The Docs <http://sphinxcontrib-contentui.readthedocs.io/en/latest/>`_


.. Links:
.. _Sphinx: http://sphinx.pocoo.org/`

